xquery version "3.1";

module namespace options="http://mollenhauer-edition.de/ns/options";

declare namespace tei="http://www.tei-c.org/ns/1.0";
declare namespace html="http://www.w3.org/1999/xhtml";
declare namespace index="https://mollenhauer-edition.de/index";

import module namespace config="https://sade.textgrid.de/ns/config" at "../../config.xqm";
import module namespace kwic="http://exist-db.org/xquery/kwic";

import module namespace search="http://mollenhauer-edition.de/ns/search" at "search.xqm";
import module namespace lang="https://sade.textgrid.de/ns/lang" at "../../lang.xqm";

declare function options:get-options($search)
as element(ol)
{
    element ol {
        attribute class {"search-param-group"},
        attribute role {"list"},
        options:main-wit($search)
    }
};

declare function options:main-wit($search)
as element(li)
{
    element li {
        attribute class { "search-param" },
        element h2 { lang:translate("views") },
        element ol {
            attribute class {"search-list"},
            attribute role {"list"},
            options:option("view", "other"),
            options:option("view", "digital"),
            options:option("view", "commentary")
        }
    }
};

declare function options:option($option as xs:string, $value as xs:string)
as element(li)
{
    let $active-values := request:get-parameter($option, "") => tokenize()
    return
        if ($active-values => filter(function($f as xs:string) {$f eq $value})) then
            element li {
                element a {
                    attribute class {"search-option search-option-active"},
                    attribute href {
                        "search.html?" ||
                        options:remove-from-query($option, $value)
                    },
                    element span {
                        attribute class {"fa fa-check-square"}
                    },
                    element span {
                        lang:translate("option-" || $value)
                    }
                }
            }
        else
            element li {
                element a {
                    attribute class {"search-option"},
                    attribute href {
                        "search.html?" ||
                        options:add-to-query($option, $value)
                    },
                    element span {
                        attribute class {"far fa-square"}
                    },
                    element span {
                        lang:translate("option-" || $value)
                    }
                }
            }
};


declare function options:add-to-query($option as xs:string, $value as xs:string)
as xs:string
{
    let $option-param := $option || "="
    let $query := request:get-query-string()
    let $params := $query => tokenize("&amp;")
    let $values := $params => filter(function($param as xs:string) {contains($param, $option-param)})
    return
        if (empty($values)) then
            $query || "&amp;" || $option-param || $value
        else
            string-join(
                for $param in $params
                where not(contains($param, $option-param)) return
                    $param,
                "&amp;"
            )
            || "&amp;" || $values || "+" || $value
};

declare function options:remove-from-query($option as xs:string, $value as xs:string) {
    let $option-param := $option || "="
    let $query := request:get-query-string()
    let $params := $query => tokenize("&amp;")
    let $values := $params => filter(function($param as xs:string) {contains($param, $option-param)})
    let $all-values := $values => substring-after($option-param) => tokenize("\+")
    let $cleared-values := $all-values => filter(function($f as xs:string?) {not($f eq $value)})
    let $query-values := string-join($cleared-values, "+")
    return
        string-join(
            for $param in $params
            where not(contains($param, $option-param)) return
                $param,
            "&amp;"
        )
        || (if (empty($cleared-values)) then "" else "&amp;" || $option-param || $query-values)
};